import pytest
from shopyo.api import validators


class TestValidators:
    """Tests validator methods"""

    @pytest.mark.parametrize(
        "url,expected",
        [
            ("google", False),
            ("www.google.com", True), ("https://www.google.com", True),
            ("localhost:3000", True), ("192.168.0.250", True),
            ("2001:0db8:85a3:0000:0000:8a2e:0370:7334", True)
        ]
    )
    def test_is_valid_url(self, url, expected):
        result = validators.is_valid_url(url)
        assert result == expected



import json
import datetime
from app import app
from modules.box__default.auth.models import User


def add_admin(email, password):
    with app.app_context():
        user = User()
        user.email = email
        user.password = password
        user.is_admin = True
        user.is_email_confirmed = True
        user.email_confirm_date = datetime.datetime.now()
        user.save()


def upload(verbose=False):
    with open("config.json", "r") as config:
        config = json.load(config)
        add_admin(
            config["admin_user"]["email"], config["admin_user"]["password"]
        )

        if verbose:
            print("[x] Added Admin User")



from shutil import copytree
import subprocess
import pytest
import sys
import os
from shopyo import __version__


pytestmark = pytest.mark.cli_integration


@pytest.mark.usefixtures("restore_cwd")
def test_initialise_after_new(tmp_path):
    """run shopyo new inside a tmp directory foo, create a venv, install the
    shopyo.tar.gz dependencies, then run `shopyo initialise`.
    """
    # go one level up to the cwd so we are are the root where
    # setup.py exits
    os.chdir("../")
    # create the dist folder with shoypo-<version>.tar.gz file
    subprocess.check_call([sys.executable, "setup.py", "sdist"])
    # store all path names to be used later
    dist_path = os.path.join(os.getcwd(), "dist")
    shopyo_dist_name = f"shopyo-{__version__}.tar.gz"
    project_path = tmp_path / "foo"
    print(project_path)
    # copy the shopyo dist to the test project path
    copytree(dist_path, os.path.join(project_path, "dist"))
    # change cwd to that of test project
    os.chdir(project_path)
    # create a new virtual environment(venv)
    subprocess.check_call([sys.executable, "-m", "venv", "env"])
    # store path for python and shopyo executable of venv for the case when OS
    #  is Unix
    python_env = os.path.join(os.getcwd(), "env", "bin", "python")
    shopyo_env = os.path.join(os.getcwd(), "env", "bin", "shopyo")
    # if OS is Windows, update the python and shopyo executable
    if sys.platform == "win32":
        python_env = os.path.join(os.getcwd(), "env", "Scripts", "python")
        shopyo_env = os.path.join(os.getcwd(), "env", "Scripts", "shopyo")
    # update pip of venv
    subprocess.check_call(
        [python_env, "-m", "pip", "install", "--upgrade", "pip"]
    )
    # install the shopyo package from dist added earlier
    subprocess.check_call(
        [
            python_env,
            "-m",
            "pip",
            "install",
            os.path.join("dist", shopyo_dist_name)
        ]
    )
    # run shopyo help command followed by new command
    subprocess.check_call(["shopyo", "--help"])
    subprocess.check_call([shopyo_env, "new"])
    # change the cwd to the newly created shopyo project
    os.chdir(os.path.join(project_path, "foo"))
    # initialise the project
    subprocess.check_call(
        [shopyo_env, "initialise"]
    )

    assert os.path.exists("shopyo.db")
    assert os.path.exists("migrations")



import json
import os

from flask import Blueprint
from flask import jsonify
from flask import redirect
from flask import render_template
from flask import request

from flask_login import login_required

from init import db
from init import ma

from modules.box__bizhelp.appointment.models import Appointments

dirpath = os.path.dirname(os.path.abspath(__file__))
module_info = {}

with open(dirpath + "/info.json") as f:
    module_info = json.load(f)

appointment_blueprint = Blueprint(
    "appointment",
    __name__,
    template_folder="templates",
    url_prefix=module_info["url_prefix"],
)


class AppointmentSchema(ma.Schema):
    class Meta:
        # Fields to expose
        fields = ("id", "name", "date", "time", "active")


appointment_schema = AppointmentSchema()
appointment_schema = AppointmentSchema(many=True)


@appointment_blueprint.route("/")
@login_required
def index():
    context = {}

    context["appointments"] = Appointments.query.all()
    return render_template("appointment/index.html", **context)


@appointment_blueprint.route("/add", methods=["GET", "POST"])
@login_required
def add():
    context = {}

    if request.method == "POST":
        name = request.form["name"]
        date = request.form["date"]
        active = request.form["active"]
        time = request.form["time"]
        m = Appointments(name=name, date=date, time=time, active=active)
        db.session.add(m)
        db.session.commit()
        return redirect("/appointment/add")
    return render_template("appointment/add.html", **context)


@appointment_blueprint.route("/delete/<ids>", methods=["GET", "POST"])
@login_required
def appointment_delete(ids):
    Appointments.query.filter(Appointments.id == ids).delete()
    db.session.commit()
    return redirect("/appointment")


@appointment_blueprint.route("/edit/<ids>", methods=["GET", "POST"])
@login_required
def appointment_edit(ids):
    context = {}

    a = Appointments.query.get(ids)
    context["id"] = a.id
    context["name"] = a.name
    context["date"] = a.date
    context["time"] = a.time
    context["active"] = a.active
    return render_template("appointment/edit.html", **context)


@appointment_blueprint.route("/update", methods=["GET", "POST"])
@login_required
def appointment_update():
    appointment_name = request.form["appointment_name"]
    appointment_date = request.form["appointment_date"]
    appointment_time = request.form["appointment_time"]
    appointment_id = request.form["appointment_id"]
    appointment_active = request.form["appointment_active"]
    s = Appointments.query.get(appointment_id)
    s.name = appointment_name
    s.date = appointment_date
    s.time = appointment_time
    s.active = appointment_active
    db.session.commit()
    return redirect("/appointment")


@appointment_blueprint.route("/active/<ids>", methods=["GET", "POST"])
@login_required
def active(ids):
    s = Appointments.query.get(ids)
    s.active = "active"
    db.session.commit()
    return redirect("/appointment")


@appointment_blueprint.route("/inactive/<ids>", methods=["GET", "POST"])
@login_required
def deactive(ids):
    s = Appointments.query.get(ids)
    s.active = "inactive"
    db.session.commit()
    return redirect("/appointment")


@appointment_blueprint.route("/lookup", methods=["GET", "POST"])
@login_required
def lookup():
    context = {}
    context["appointments"] = Appointments.query.all()
    return render_template("appointment/lookup.html", **context)


# api
@appointment_blueprint.route("/search/name/<name>", methods=["GET", "POST"])
@login_required
def search_name(name):
    if name == "searchValueIsEmpty":
        all_a = Appointments.query.all()
    else:
        all_a = Appointments.query.filter(
            Appointments.name.like("%" + name + "%")
        ).all()
    result = appointment_schema.dump(all_a)
    return jsonify(result)



import json
import os

from flask import Blueprint

dirpath = os.path.dirname(os.path.abspath(__file__))
module_info = {}

with open(dirpath + "/info.json") as f:
    module_info = json.load(f)

base_blueprint = Blueprint(
    "base",
    __name__,
    url_prefix=module_info["url_prefix"],
    template_folder="templates",
)



"""
All initialisations like db = SQLAlchemy in this file
"""

import os

from flask_login import LoginManager
from flask_marshmallow import Marshmallow
from flask_migrate import Migrate
from flask_sqlalchemy import SQLAlchemy
from flask_mailman import Mail

root_path = os.path.dirname(os.path.abspath(__file__))  # don't remove
static_path = os.path.join(root_path, "static")  # don't remove
modules_path = os.path.join(root_path, "modules")  # don't remove
themes_path = os.path.join(static_path, "themes")  # don't remove

db = SQLAlchemy()
ma = Marshmallow()
login_manager = LoginManager()
migrate = Migrate()
mail = Mail()



import requests
from bs4 import BeautifulSoup
from pprint import pprint

site_url = 'https://defimedia.info/'
header = {'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:32.0) Gecko/20100101 Firefox/32.0',}
titles = requests.get(site_url, headers=header).content
moon_soup = BeautifulSoup(titles, 'html.parser')
rows = table.find_all('sup-title')
print(rows)


import datetime
import json
import os

from flask import Blueprint
from flask import jsonify
from flask import redirect
from flask import render_template
from flask import request

from flask_login import login_required

from init import db
from init import ma

from modules.box__bizhelp.people.models import People

dirpath = os.path.dirname(os.path.abspath(__file__))
module_info = {}

with open(dirpath + "/info.json") as f:
    module_info = json.load(f)

people_blueprint = Blueprint(
    "people",
    __name__,
    template_folder="templates",
    url_prefix=module_info["url_prefix"],
)


class PeopleSchema(ma.Schema):
    class Meta:
        # Fields to expose
        fields = (
            "id",
            "name",
            "phone",
            "mobile",
            "email",
            "facebook",
            "twitter",
            "linkedin",
            "age",
            "birthday",
            "notes",
            "is_manufacturer",
            "manufacturer_name",
            "manufacturer_phone",
            "manufacturer_address",
        )


people_schema = PeopleSchema()
people_schema = PeopleSchema(many=True)


@people_blueprint.route("/")
@login_required
def index():
    context = {}

    context["people"] = People.query.all()
    return render_template("people/index.html", **context)


@people_blueprint.route("/add", methods=["GET", "POST"])
@login_required
def people_add():
    context = {}

    if request.method == "POST":
        name = request.form["name"]
        phone = request.form["phone"]
        mobile = request.form["mobile"]
        email = request.form["email"]
        linkedin = request.form["linkedin"]
        facebook = request.form["facebook"]
        twitter = request.form["twitter"]
        birthday = request.form["birthday"]
        notes = request.form["notes"]
        is_manufacturer = request.form.get("is_manufacturer", False)
        manufacturer_name = request.form.get("manufacturer_name", "")
        manufacturer_phone = request.form.get("manufacturer_phone", None)
        manufacturer_address = request.form.get("manufacturer_address", "")

        # check if is_manufacturer is true
        if is_manufacturer == "on":
            is_manufacturer = True

        # calculate age
        today_date = datetime.date.today()
        date_format = "%Y-%m-%d"
        b_day = datetime.datetime.strptime(birthday, date_format)
        age = (
            today_date.year
            - b_day.year
            - ((today_date.month, today_date.day) < (b_day.month, b_day.day))
        )

        # insert data into DB
        person = People(
            name=name,
            phone=phone,
            mobile=mobile,
            email=email,
            linkedin=linkedin,
            facebook=facebook,
            twitter=twitter,
            age=age,
            birthday=birthday,
            notes=notes,
            is_manufacturer=is_manufacturer,
            manufacturer_name=manufacturer_name,
            manufacturer_phone=manufacturer_phone,
            manufacturer_address=manufacturer_address,
        )
        db.session.add(person)
        db.session.commit()
        return redirect("/people/add")
    context["message"] = ""
    return render_template("people/add.html", **context)


@people_blueprint.route("/delete/<id>", methods=["GET", "POST"])
@login_required
def people_delete(id):
    People.query.filter(People.id == id).delete()
    db.session.commit()
    return redirect("/people")


@people_blueprint.route("/edit/<id>", methods=["GET", "POST"])
@login_required
def people_edit(id):
    context = {}

    a = People.query.get(id)

    context["id"] = a.id
    context["name"] = a.name
    context["phone"] = a.phone
    context["mobile"] = a.mobile
    context["email"] = a.email
    context["linkedin"] = a.linkedin
    context["facebook"] = a.facebook
    context["twitter"] = a.twitter
    context["age"] = a.age
    context["birthday"] = a.birthday
    context["notes"] = a.notes
    context["is_manufacturer"] = a.is_manufacturer
    context["manufacturer_name"] = a.manufacturer_name
    context["manufacturer_phone"] = a.manufacturer_phone
    context["manufacturer_address"] = a.manufacturer_address
    return render_template("people/edit.html", **context)


@people_blueprint.route("/update", methods=["GET", "POST"])
@login_required
def people_update():
    if request.method == "POST":
        people_id = request.form["id"]
        people_name = request.form["name"]
        people_phone = request.form["phone"]
        people_mobile = request.form["mobile"]
        people_email = request.form["email"]
        people_linkedin = request.form["linkedin"]
        people_facebook = request.form["facebook"]
        people_twitter = request.form["twitter"]
        people_birthday = request.form["birthday"]
        people_notes = request.form["notes"]
        people_is_manufacturer = request.form.get("is_manufacturer", False)
        people_manufacturer_name = request.form.get("manufacturer_name", "")
        people_manufacturer_phone = request.form.get
        ("manufacturer_phone", None)
        people_manufacturer_address = request.form.get
        ("manufacturer_address", "")

        # check if is_manufacturer is true
        if people_is_manufacturer == "on":
            people_is_manufacturer = True

        # calculate age
        today_date = datetime.datetime.now()
        time_format = "%Y-%m-%d"
        b_day = datetime.datetime.strptime(people_birthday, time_format)
        people_age = str(today_date - b_day)
        # retrive record from db with id
        s = People.query.get(people_id)
        s.name = people_name
        s.phone = people_phone
        s.mobile = people_mobile
        s.email = people_email
        s.facebook = people_facebook
        s.linkedin = people_linkedin
        s.twitter = people_twitter
        s.birthday = people_birthday
        s.notes = people_notes
        s.age = people_age
        s.is_manufacturer = people_is_manufacturer
        s.manufacturer_name = people_manufacturer_name
        s.manufacturer_phone = people_manufacturer_phone
        s.manufacturer_address = people_manufacturer_address
        db.session.commit()

        return redirect("/people")


@people_blueprint.route("/lookup", methods=["GET", "POST"])
@login_required
def lookup():
    context = {}
    context["people"] = People.query.all()
    return render_template("people/lookup.html", **context)


# api
@people_blueprint.route("/search/name/<name>", methods=["GET", "POST"])
@login_required
def search_name(name):
    if name == "searchValueIsEmpty":
        all_a = People.query.all()
    else:
        all_a = People.query.filter(People.name.like("%" + name + "%")).all()
    result = people_schema.dump(all_a)
    return jsonify(result)



"""
This file (test_contact.py) contains the functional tests for the
`contact` blueprint.

These tests use GETs and POSTs to different endpoints to check for
the proper behavior of the `contact` blueprint.
"""
from flask import request
from flask import url_for


def test_contact_page(test_client):
    """
    GIVEN a Flask application configured for testing,
    WHEN the /contact page is requested (GET)
    THEN check that the response is valid
    """
    response = test_client.get("/contact/")
    assert response.status_code == 200
    assert b"Name" in response.data
    assert b"Email" in response.data
    assert b"Message" in response.data
    assert b"Submit" in response.data


def test_contact_dashboard(test_client):
    """
    GIVEN a Flask application configured for testing,
    WHEN the /contact/dashboard page is requested (GET)
    THEN check that the response is valid
    """
    # Logout and try to access the contact dashboard. It should redirect
    response = test_client.get(url_for("auth.logout"), follow_redirects=True)
    print(request.path)
    assert response.status_code == 200
    assert request.path == url_for("auth.login")

    # check request to contact correctly redirects to login page
    response = test_client.get("/contact/dashboard", follow_redirects=True)
    assert request.path == url_for("auth.login")

    # Login and try to access the contact dashboard. It should return OK
    response = test_client.post(
        url_for("auth.login"),
        data=dict(email="admin1@domain.com", password="pass"),
        follow_redirects=True,
    )

    # check if successfully logged in
    assert response.status_code == 200

    # check response is valid
    response = test_client.get(url_for("contact.dashboard"))
    assert response.status_code == 200
    assert b"Contact dashboard" in response.data
    assert b"Name" in response.data
    assert b"Mail" in response.data
    assert b"Date" in response.data
    assert b"Info" in response.data
    assert b"View message" not in response.data


def test_contact_validate_msg(test_client):
    """
    GIVEN a Flask application configured for testing,
    WHEN POST request is made contact validate page
    THEN check that the response is valid and that
    the new validated message appears on contact dashboard
    """
    # GET request should fail for validate message
    # Currently test is uncommented since no return statement for
    # validate_message for GET
    # UNCOMMENT BELOW CODE AFTER FIXING validate_message
    # response = test_client.get(url_for("contact.validate_message"))
    # assert response.status_code != 200

    # add a message
    response = test_client.post(
        url_for("contact.validate_message"),
        data=dict(
            name="User1", email="user1@gmail.com", message="User1 Message"
        ),
        follow_redirects=True,
    )
    assert response.status_code == 200

    # check if message was added successfully
    response = test_client.get(url_for("contact.dashboard", page=1))
    assert response.status_code == 200
    assert b"Contact dashboard" in response.data
    assert b"User1" in response.data
    assert b"user1@gmail.com" in response.data
    assert b"User1 Message" in response.data
    assert b"View message" in response.data

    # change contact page and make sure the message is not there
    response = test_client.get(url_for("contact.dashboard", page=2))
    assert response.status_code == 200
    assert b"User1" not in response.data
    assert b"user1@gmail.com" not in response.data
    assert b"User1 Message" not in response.data
    assert b"View message" not in response.data
